package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(J``````````0```````
M`+&8``````!``#@`"0!``!H`&0````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*:(````````IH@`
M```````0``````$````&````````J\@```````"[R````````+O(````````
M!,`````````$Z````````!```````@````8```````"KV````````+O8````
M````N]@````````"``````````(```````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````GV@```````"?:````````)]H`````````.P`````````[```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*O(````````N\@`````
M``"[R`````````0X````````!#@``````````2]L:6(O;&0V-"YS;RXQ````
M```$````%`````-'3E4`&JEL@6>2YH/NPNNPATKRWN%X1_4````$````$```
M``%'3E4```````````,````"```````````````1````0P````0````(A`1`
M!0`0$""$`(:`!``"*`@$(`D"`(F""`(`ND$0@(@`````````0P```$8```!)
M````2@```%(```!3````5`````````!6````5P```%@```!9````6@```%P`
M`````````!_?Q6XM1][.?)I_:[:;Q2Y\U&34#N3_(1Q8<=D!QD?B;XL!LL#C
M2ZR'U_I"+#_EPGR2X[I@;*'ZF\-/F=9#"6MFS*]G[-5%0M-P!XGMVV(SS"6,
M%0N7.@V;G*E_"@*GX%">&FM)^^"C````````````````````````````````
M```````````#```+````````&/@``````````````V@2````````````````
M`````````````.02`````````````````````````````K01````````````
M`````````````````H02`````````````````````````````)82````````
M`````````````````````5T2`````````````````````````````;42````
M`````````````````````````/H2`````````````````````````````>X2
M``````````````````````````````$@````````````````````````````
M`702`````````````````````````````KP2````````````````````````
M`````9P2`````````````````````````````>,2````````````````````
M`````````2L2`````````````````````````````=P2````````````````
M`````````````1L2`````````````````````````````0T2````````````
M`````````````````=02`````````````````````````````JH2````````
M`````````````````````!`@`````````````````````````````7L2````
M`````````````````````````A$2`````````````````````````````K(1
M`````````````````````````````E\2````````````````````````````
M`"P@`````````````````````````````C\2````````````````````````
M`````$82`````````````````````````````AH2````````````````````
M`````````&,6`````````````````````````````4T2````````````````
M`````````````:X2`````````````````````````````'82````````````
M`````````````````-,2`````````````````````````````(<2````````
M`````````````````````:02`````````````````````````````F8B````
M`````````````````````````ID2`````````````````````````````9<2
M`````````````````````````````+<2````````````````````````````
M`?42`````````````````````````````@H2````````````````````````
M`````?L2`````````````````````````````3\2````````````````````
M`````````.X2`````````````````````````````882````````````````
M`````````````G42`````````````````````````````C`2````````````
M`````````````````CX2`````````````````````````````<T2````````
M`````````````````````*(2`````````````````````````````>D2````
M`````````````````````````6@2`````````````````````````````.D2
M`````````````````````````````;X2````````````````````````````
M`,81`````````````````````````````<42````````````````````````
M`````HL2`````````````````````````````B(2````````````````````
M`````````302`````````````````````````````GP2````````````````
M`````````````%02`````````````````````````````D82````````````
M`````````````````I(2`````````````````````````````E@1````````
M`````````````````````W$2```-````````0F``````````U@```\82```-
M````````.8`````````&F````E,2```-````````(!@````````"B````N@2
M```-````````*X@`````````!@```P82```-````````0!@````````"1```
M`^P2```-````````*Y`````````"7````ZP0```7````````P(@`````````
M`````OD2```-````````+?``````````-@```QP2```-````````-5``````
M````>````WT1```/````````7M@`````````!````YD2```-````````6F``
M```````!R@```Z02```-````````*G@`````````.````\$0```7````````
MP+```````````````]H2```-````````.'`````````!"@``!`,2```-````
M````-<@`````````>````XP0```6````````P````````````````T`2```-
M````````+B@````````!2````],0```7````````P(@``````````````_D1
M```6````````P(``````````"````Y(2```-````````(J``````````````
M`[@2```-````````6?``````````;````XX@```6````````P```````````
M`````U82```-````````.$``````````+@```RH2```-````````*K``````
M````U````TP2```-````````7#`````````":```!`L2```-````````+W``
M```````%W`!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M
M`%!E<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L7V%T9F]R
M:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?
M;F]C;VYT97AT`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE
M=UA37V9L86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U
M;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`
M4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P97)L
M7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%]?<W1A8VM?
M8VAK7V9A:6P`97AI=`!L<V5E:S8T`')E861D:7(V-`!S=')D=7``8VQO<V5D
M:7(`;W!E;C8T`'-T<G)C:'(`=6YL:6YK`&UE;6UO=F4`<W1R=&]K`')M9&ER
M`')E860`<W1R<W1R`&UK9&ER`%]?=F9P<FEN=&9?8VAK`&=E='!I9`!R96%D
M;&EN:P!R96%L;&]C`%]?<W!R:6YT9E]C:&L`7U]F<')I;G1F7V-H:P!L<W1A
M=#8T`%]?;&EB8U]S=&%R=%]M86EN`'-T9&5R<@!M96UC:'(`7U]C>&%?9FEN
M86QI>F4`<W1R8VAR`&]P96YD:7(`9V5T=6ED`&%C8V5S<P!M96UC<'D`7U]E
M<G)N;U]L;V-A=&EO;@!S=')N8VUP`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T
M9F]R:P!L:6)P97)L+G-O+C4N,S@`;&EB8RYS;RXV`'!A<E]C=7)R96YT7V5X
M96,`<&%R7V)A<V5N86UE`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV
M7V-L96%N`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!S:&%?
M9FEN86P`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``
M7TE/7W-T9&EN7W5S960`7U]D871A7W-T87)T`'-H85]U<&1A=&4`>'-?:6YI
M=`!?7V)S<U]S=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M:W1M<&1I<@!?961A
M=&$`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P
M87)?9&EE`'!A<E]I;FET7V5N=@!'3$E"0U\R+C,T`$=,24)#7S(N-`!'3$E"
M0U\R+C,S`$=,24)#7S(N,RXR`$=,24)#7S(N,@````````(``0`"``(``0`!
M``(``0`"``$``@`#``(``@`!``(``0`!``(``@`!``$``@`"``(``0`$``$`
M`@`!``$``@`!``$``0`"``(``@`"``$``@`"``4``0`!``4``@`%``0``@`!
M``(``0`"``(``0`"``(`!0`!``(``0`&``(``@`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`%```"W@``
M`!``````!I:1M`````8```08````$`UI:10````%```$(P```!`&EI&S````
M!```!"T````0"6D9<@````,```0X````$`UI:1(````"```$1```````````
M``"[R``````````,````````(Y````````"[T``````````,````````(T@`
M``````"_^``````````,````````(!@```````#`"``````````,````````
MP`@```````#`(``````````,````````8=8```````#`*``````````,````
M````7S0```````#`.``````````,````````7]0```````#`0``````````,
M````````7]@```````#`2``````````,````````8<H```````#`4```````
M```,````````7SH```````#`6``````````,````````8=(```````#`:```
M```````,````````8;H```````#`<``````````,````````8<````````#`
M@``````````,````````8=P```````"_H`````0````*````````````````
M``"_J`````D````*``````````````````"_L`````L````*````````````
M``````"_N````!8````*``````````````````"_P````!L````*````````
M``````````"_R````!\````X``````````````````"_T````"`````*````
M``````````````"_V````"(````*``````````````````"_X````"8````*
M``````````````````"_Z````#D````*``````````````````"_\````$(`
M```*``````````````````"]\`````(````+``````````````````"]^```
M``,````+``````````````````"^``````4````+``````````````````"^
M"`````8````+``````````````````"^$`````<````+````````````````
M``"^&`````@````+``````````````````"^(`````H````+````````````
M``````"^*`````P````+``````````````````"^,`````T````+````````
M``````````"^.`````X````+``````````````````"^0`````\````+````
M``````````````"^2````!`````+``````````````````"^4````!$````+
M``````````````````"^6````!(````+``````````````````"^8````!,`
M```+``````````````````"^:````!0````+``````````````````"^<```
M`!4````+``````````````````"^>````!<````+``````````````````"^
M@````!@````+``````````````````"^B````!H````+````````````````
M``"^D````!P````+``````````````````"^F````!T````+````````````
M``````"^H````!X````+``````````````````"^J````"$````+````````
M``````````"^L````",````+``````````````````"^N````"0````+````
M``````````````"^P````"4````+``````````````````"^R````"8````+
M``````````````````"^T````"<````+``````````````````"^V````"@`
M```+``````````````````"^X````"D````+``````````````````"^Z```
M`"H````+``````````````````"^\````"L````+``````````````````"^
M^````"P````+``````````````````"_`````"T````+````````````````
M``"_"````"X````+``````````````````"_$````"\````+````````````
M``````"_&````#`````+``````````````````"_(````#$````+````````
M``````````"_*````#(````+``````````````````"_,````#,````+````
M``````````````"_.````#0````+``````````````````"_0````#4````+
M``````````````````"_2````#8````+``````````````````"_4````#<`
M```+``````````````````"_6````#@````+``````````````````"_8```
M`#H````+``````````````````"_:````#L````+``````````````````"_
M<````#P````+``````````````````"_>````#T````+````````````````
M``"_@````#X````+``````````````````"_B````#\````+````````````
M``````"_D````$`````+``````````````````"_F````$$````+````````
M``#K;_`P`"2Y!``?I_O_8.,0\```),#```!29L`0``!33^,0$```!+D"`!&G
MA``##>'C0/$0``3K;_#0``0']`<'XQ#P.``DP!```%)-T@?P,!`(XQ`0$``$
M!_$'``<`!P#`$```4DSC$!````0'\0T0XQ`0#``4P/3____E`````,`0``!2
M0.,0$```!`?Q#1#C$!`,`!3`]/___]4````8P!```%(TXQ`0```$!_$-$.,0
M$`P`%,#T____Q0```##`$```4BCC$!````0'\0T0XQ`0#``4P/3___^U````
M2,`0``!2'.,0$```!`?Q#1#C$!`,`!3`]/___Z4```!@P!```%(0XQ`0```$
M!_$-$.,0$`P`%,#T____E0```'C`$```4@3C$!````0'\0T0XQ`0#``4P/3_
M__^%````D,`0``!1^.,0$```!`?Q#1#C$!`,`!3`]/___W4```"HP!```%'L
MXQ`0```$!_$-$.,0$`P`%,#T____90```,#`$```4>#C$!````0'\0T0XQ`0
M#``4P/3___]5````V,`0``!1U.,0$```!`?Q#1#C$!`,`!3`]/___T4```#P
MP!```%'(XQ`0```$!_$-$.,0$`P`%,#T____-0```0C`$```4;SC$!````0'
M\0T0XQ`0#``4P/3___\E```!(,`0``!1L.,0$```!`?Q#1#C$!`,`!3`]/__
M_Q4```$XP!```%&DXQ`0```$!_$-$.,0$`P`%,#T____!0```5#`$```49CC
M$!````0'\0T0XQ`0#``4P/3___[U```!:,`0``!1C.,0$```!`?Q#1#C$!`,
M`!3`]/___N4```&`P!```%&`XQ`0```$!_$-$.,0$`P`%,#T___^U0```9C`
M$```473C$!````0'\0T0XQ`0#``4P/3___[%```!L,`0``!1:.,0$```!`?Q
M#1#C$!`,`!3`]/___K4```'(P!```%%<XQ`0```$!_$-$.,0$`P`%,#T___^
MI0```>#`$```45#C$!````0'\0T0XQ`0#``4P/3___Z5```!^,`0``!11.,0
M$```!`?Q#1#C$!`,`!3`]/___H4```(0P!```%$XXQ`0```$!_$-$.,0$`P`
M%,#T___^=0```BC`$```42SC$!````0'\0T0XQ`0#``4P/3___YE```"0,`0
M``!1(.,0$```!`?Q#1#C$!`,`!3`]/___E4```)8P!```%$4XQ`0```$!_$-
M$.,0$`P`%,#T___^10```G#`$```40CC$!````0'\0T0XQ`0#``4P/3___XU
M```"B,`0``!0_.,0$```!`?Q#1#C$!`,`!3`]/___B4```*@P!```%#PXQ`0
M```$!_$-$.,0$`P`%,#T___^%0```KC`$```4.3C$!````0'\0T0XQ`0#``4
MP/3___X%```"T,`0``!0V.,0$```!`?Q#1#C$!`,`!3`]/___?4```+HP!``
M`%#,XQ`0```$!_$-$.,0$`P`%,#T___]Y0```P#`$```4,#C$!````0'\0T0
MXQ`0#``4P/3___W5```#&,`0``!0M.,0$```!`?Q#1#C$!`,`!3`]/___<4`
M``,PP!```%"HXQ`0```$!_$-$.,0$`P`%,#T___]M0```TC`$```4)SC$!``
M``0'\0T0XQ`0#``4P/3___VE```#8,`0``!0D.,0$```!`?Q#1#C$!`,`!3`
M]/___94```-XP!```%"$XQ`0```$!_$-$.,0$`P`%,#T___]A0```Y#`$```
M4'CC$!````0'\0T0XQ`0#``4P/3___UU```#J,`0``!0;.,0$```!`?Q#1#C
M$!`,`!3`]/___64```/`P!```%!@XQ`0```$!_$-$.,0$`P`%,#T___]50``
M`]C`$```4%3C$!````0'\0T0XQ`0#``4P/3___U%```#\,`0``!02.,0$```
M!`?Q#1#C$!`,`!3`]/___34```0(P!```%`\XQ`0```$!_$-$.,0$`P`%,#T
M___])0``!"#`$```4##C$!````0'\0T0XQ`0#``4P/3___T5```$.,`0``!0
M).,0$```!`?Q#1#C$!`,`!3`]/___04```10P!```%`8XQ`0```$!_$-$.,0
M$`P`%,#T___\]0``!&C`$```4`SC$!````0'\0T0XQ`0#``4P/3___SE```$
M@,`0``!0`.,0$```!`?Q#1#C$!`,`!3`]/___-4```28P!```$_TXQ`0```$
M!_$-$.,0$`P`%,#T___\Q0``!+#`$```3^CC$!````0'\0T0XQ`0#``4P/3_
M__RU```$R,`0``!/W.,0$```!`?Q#1#C$!`,`!3`]/___*4```3@P!```$_0
MXQ`0```$!_$-$.,0$`P`%,#T___\E0``!/CK;_`P`"3C\/\X_W'C,/"H`"3C
M0/"@`"10(/"T04#PH$$P\*A!(/"TLD\`L.N[`"``#;)/`+'2!_#`L"C`Y?__
M_[+$2```3Z?$*```3[RY!``TP.4``!\7Q!@``$^\E0`0`*>$`+C`,```3Z7C
M4#````18H/"T[)H`!`#8N10`Z>-EL```!.LN``,`#98#9(JGJ@`#P.7___\&
MXQ#PJ``$P#```"!]XP`0```$XS`@"``DXP`@```DN00`4L0K``!/XL!````@
M;N-`4!@`),0H``!/S>,@4!``)%B0\+2GG@`!I\0`Q^SI``,`V.P)__\`V$$P
M$`BG*``$IP$``:=T`(2(```!N10`0NP2``$`V.OD``,`#;D4`&'C0#````3C
M3E```"3K%@`#``WC8#`(``3C85```"2G*@`"ISL`$*<&_^/L:0`#`-BY%`"6
MZSD``P`-N10`2J=I``!!HU``Q"@``$^8Y4B@````P#````0^P.7___PG$B*G
MA`!5Q"@``$^)06#PO,#E___]_+D$`#:Y!`"2P"```![LP.4```#RN0(`(J>$
M`$?$*```3W/`Y?__^]C`Y?___175!_#`L"BG=`!;N00`*>MO\/@`!`?^P.7_
M__S'Q"L``$]<N0(`(J>$`$[`Y?___3W`,```3N+C(#````3C0K````22`$E^
MI_3_->,P,```!.,P4"``)*<H``5!,!`0&2ZG=/]SI_3_DL0H``!/-L#E___\
M.Z?T_Z?`4```3RKC(%````*GA``'P.4``!`"I_3_L+D$`#;`(```'F;`Y0``
M`)3$*P``3Q6Y`@`BIX3_H:?T_^RG:``$I_3_:\#E___]I*<I``'`Y?___2]!
M0/`(XS#P```$IPG_\+F``/"G^_]0UP?P`/``Z^_PH``D07#PH*=I``"G60``
MP"```$Z5XR`@```$P.7___Y_```'!P<'!P?`$```3M#`(```3LVY(``2!X[$
M&```3E^Y`@`1!XX'\<`0``!.P,`@``!.O;D)`!+K`0`#``KK,0`_``RY"``P
MZS,``0`*N0(`,P>.Q!@``$Y&N0(`$0>.P"```$ZD!_'KO_!8`"3`L```3IWC
M\/]@_W&5`+``IW0`%<`0``!./^,0$````J>$``C$*```3DO`Y?___*#`Y?__
M_[62`;``Z[_P^``$!_[`]/___[P'!^MO\#``)./P_V#_<;D"`(*GA`!:Q!@`
M`$WZXW`0```"IX0`4KD$`&/C`(```)2Y!`"8E0"``*>$`$^G#@`]IX0`"T&0
MD`'C`)```)25`)``IW3_]1N8XZ!P```"IX0`'[D4`)FY!`"WN00`2;D$`#BY
M!``JP.7___NF$B*G=``(02F@`)4](`"GA``/0;"P"..@L````J=T_^FY!``J
MZV_PT``$!_Y!J:`!N>EP.[D$`"KK0P`#``I00&``ZV_PT``$!_ZGJ0``N00`
M*NMO\-``!`?^IY@``*?T_[\'!P<'ZZ_P4``DX_#^R/]QLD\`L+D$`*+KNP`@
M``U!,/"@LD\`L=('\3"P*,#E___\S!(BIW0`'Q@26"#PN,`K``#P`*<N0`"G
MA``'PBT``*``IW0`$KD$`"JG.0`"P.7___TS$!*G&O__B!``'Z?T``2G&```
MN10`(=4'\3"P**=T``;KK_&(``0'_L#E___\;`<'ZV_P,``DX_#^P/]QLD\`
MH.NJ`"``#;)/`*&Y`@!BT@?Q.*`HIX0`!I4`8`"G=``+U0?Q.*`HIW0`D^MO
M\7``!`?^P.7___TGN0(`DJ>$__*Y!``IP.7___N>N0(`(J>$`&1!L"`3E2X@
M$Z=T``:5`+`!IX3_[Y4N(!.GA`!BIP@``+D$`!:Y!``[ITD``*=9``"R7@!!
MIQ3__K)>`%.G%/_^N0D`1KD)`%L:1:=*``*Y%``DP.7___H^X[#PH``DP%``
M`!R*N00`LJ=)__^G.0`!P.7___R_03#PJ+D$`"O`Y?__^OBG+O__N00`*Z>$
M``M8`/#`P`L``/``IPY``*>$`"G`Y?___":Y!``KP.7___QAN00`*<#E___[
M/+D"`"*G=/^@N00`*<#E___YX[D$`";`Y?__^BZG]/][E2ZP`:=T_YZ5`+`"
MIX3_@Z?T_YC`Y?___U>G]/_9P.7___NZ!P<'!P<'ZV_P,``DX_#_2/]QLD\`
M8.MF`"``#;)/`&&Y!`"RN00`H]('\+!@*)4],`"G=``$0:`P`:<(``"Y!``:
MIXD``+)>`(&G%/_^N0D`BD$P\*RY!``KP.7___YJN0(`(J>$`)VG"```I]D`
M`+D$`!*R7@#1IQ3__KD)`-*Y(0"-I\0`>N-P\*P`%,38``!,5.MW``,`#>,@
ML```E+D$`$N5`+``IW0`#:?T`.Y!0$`!XR!```"4E0!``*>$``:G+@`]IW3_
M];D)`$NY%`"402B0`KD$`(?C@-````C`Y?__^7?C((```"2Y`@`BIX0`.^,`
ML```D.,PT```!.-7,```!$(`4`!!X+`!&'"Y`@``IW0`$*?T`#_C$.```)!"
M$+`!0>#@`1AQN0(`$:>$`#-"</"@N00`M94]\*!!4%`!IW3_[)(]L`"GV0``
MXTV@``"00DVP`:?;``&Y`@!$IW3_]]4'\+!@**=T`)CK;_#H``0'_J>9``#C
MB:```)!"B2``IYL``;D"`(BG=/_WI_3_ZKD$`+6G]/_7Q-@``$O,XW#0```$
MXQ!P```"IX0`<+D$`$>GF```&`FGF@`!04!`".,P0````J=T__BG"@`#N10`
M,.LC``,`#<!0``!,).,04```$J=T`#?`X```3!SE3.````'`Y?__^.JY`@`2
MXQ#PH``DIX3_KKD$`#>Y%`!YZW<``P`-N00`1\#E___Y5^,@\*``!.,@T```
M)%"0\*SC4/"@``2GF@`!N10`F>LY``,`#4'C4`#E2.````"G]/\CN00`,KD$
M`"?`Y?__^:?C(/"@`"3C(-```"2Y`@`BIX3_>+D4`$GK=``#``VG]/_7IYD`
M`*?T_R.G*0`0IY@``*?T_Z/`Y?__^FD'!P<'ZW_P.``DX_#_6/YQXQ#PH`%Q
MN00`HKD$`).R3P"P08#PH.N[`"``#;D$`#BR3P"QITD/_\`@```:S]('$`"P
M*,#E___Y)!(BI\0`$>P"__\`V!@2N10`($$R\*"5`#``IW0`(A(`IW0`'L!0
M``!+)^/@4```!+D$`$FY!``ZXRZP```$P.7___C"XT#PH`%QU0=``+`HIW0`
M*NM_\.`!!`?^&!"Y%`!QISD`+[D$`$>Y!``HP.7___CZN0(`(J>$_]:Y!``Z
MN00`5\"@``!*][D$`$CCD*````3C*;````3`Y?__^92G]/_2P.7___GOP!``
M`$KDP%```#JEQ$@``$KBZV_P,``DP#```!IMX[`0```$X_#_6/]QLD\`H.NJ
M`"``#;)/`*'C*Z````3`8```&[G`Y?__^IJY!`!6Y4CPH```P$````KBXRN@
M```$P#```!I7P.7___CYZV_PV``$!_X'!P<'LD\`(,`0``!*INLR`"``#>-`
M$```!+)/`#'`4```.E_C)#````3$2```2IG`,```&B?`]/__^F?K;_`P`"3C
M\/](_7'C$/"P`G&R3P"0ZYD`(``-LD\`D=('$`"0*$&P\*[C@/"O`7'`Y?__
M^3S`````&B7C`/"@`"2Y!`!BP%```!H7ITD0`:<Y``&Y!``KP.7___HHITD0
M`+D$`"NY!``XP.7___@_$B*G1``JN00`8J<J``&Y%``BP.7___>#N0(`HJ>$
M``^Y%`"VN00`.+D$`$O`Y?__^E9!.Z``D@`P`.-`\+`"<=4'0`"0**=T``RY
M!``JZV_PZ`($!_ZGJ0``I_3_\,#E___Y+0<'!P?`]/___Y0'!^MO\#``)./P
M_K#^<>,0\4@!<;D$`+*Y!`"3LD\`<$$P\+3K=P`@``W`(```&;^R3P!QT@<0
M`'`HP.7___OHISD`+[D$`**Y!``KP.7___D/N0(`(J>$`!C`(```&:RY!``[
MP.7___T_N00`*^,0\4@!<=4'$`!P**=T`._K;_&``00'_KD$`"G`Y?__^!#`
M,```&9C`Y?__]UJY`@!BIX3_W4&0\4A!@/"XE0!@`*>$`*:Y`@"JIX0`#J<(
M``"Y!``VN00`*K)=`#*G%/_^IX0`AJ<(``"G20``N00`5K)>`$6G%/_^N>E@
M).,03___<;DA`&&GI``WN>E@`:<!``&GA``/E2\0`*=T`"&2`!``XQ`?__]Q
MN2``8:>$`!CKX``!``R5+Q``IW0`$9(`$`#K+Q___U6G=``*ZP`?__]2XQ`?
M_O]QI^?_[Z<(``"G*0``N00`-K)>`".G%/_^N0D`)J<(``"G20``N00`6[)>
M`$6G%/_^N0D`2T$$(`'"#@``#_^G)/]JP.```!D<X[#PJ``DX^#PH``DP%``
M`!F)ITD0`*<Y``&Y!``IP.7___D.N00`.+D$`"G`Y?__]T<2(J=T``Q88/#0
MP&L``/``PFT``(``IX0`)\`P```8\J<I``#`Y?__]K*Y`@!BIX3_-94`8`"G
M=/]>N0(`JJ>$``:5+J``IX0`":<I``'`8```&,NG]/^GE0"@`:>$_]^G]/_U
MISD``;D$`"G`Y?__^+X2(J=T_].Y!``YP"```!BZP.7___Q/N00`*<#E___W
M+J?T_PW`Y?__]_D'!P<'Z[_P6``DISD`+^/P_V#_<;D$`++`Y?__^(JY`@`B
MIX0`!$&P(`&Y!``KZ[_P^``$P/3___<,!P?KG_!(`"3C\/]8_G&R3P"@XQ#P
MH`%QZZH`(``-LD\`H=('$`"@*+D"`#*GA`!DE0`P`*>$`&"G"```IYD``+D$
M`".R7@"2IQ3__KD)`)/L20`!`-G"3@``$`"G)`!P0;#PH+D$`"O`Y?__^+7C
M2;___W&Y(0!+I\0`'KGIL`2G00`!IW0`2>LP``$`#)4O0`"G=``1D@!``.LO
M3___5:=T``KK`$___U+C0$_^_W&G-__OISD`+[D$`"O`Y?__^!NY`@!2IX0`
M%[DA`%NG)``SN00`*\#E___VGN/@\*`!<=4'X`"@**=T`"[KG_#P`00'_N,0
M\*`!<=4'$`"@**=T`"+`(```&`7KG_#P`03`]/__]H&5+T``IW3_S9(`0`#C
M0$___W&Y(`!+IW3_KJ?T_\*2`%``I_3_S:<I``"G]/_.P.7___<WZZ_P4``D
MX_#_4/]QLD\`H$&P\*3KJ@`@``VR3P"AT@?PJ*`HN00`.\`@```7W<#E___Y
M_;D"`"*GA``PXT#PI``4Q"@``$?WZQ0``P`-XQ`@```(XU`0"``$XU`0```D
MN0(`5:>$_^#C`!`0``3C`!`(`"1!$!`(N0(``*=T__:Y!``[P"```!>OP.7_
M__G/N0(`(J=T_]2Y!``[P"```!>HP.7___G#N0(`(J>$`##C$/"D`!3$6```
M1[WKX0`#``WCX%````CC`.`(``3C`.```"2Y`@``IX3_X.,PX!``!.,PX`@`
M)$'@X`BY`@`SIW3_]KD$`#O`(```%WK`Y?__^96Y`@`BIW3_U+D$`#O`(```
M%W+`Y?__^8FY`@`BIX0`,.-0\*0`%,3H``!'@^M%``,`#>-`X```".,P0`@`
M!.,P0```)+D"`#.GA/_@XR!`$``$XR!`"``D04!`"+D"`"*G=/_VN00`.\`@
M```71,#E___Y6[D"`"*G=/_4N00`.\`@```7/<#E___Y3[D"`"*GA``PXS#P
MI``4Q"@``$=)ZQ,``P`-XQ`@```(XT`0"``$XT`0```DN0(`1*>$_^#C`!`0
M``3C`!`(`"1!$!`(N0(``*=T__:Y!``[P"```!</P.7___DAN0(`(J=T_]2Y
M!``[P"```!<'P.7___D5N0(`(J>$`##C$/"D`!3$2```1P_K40`#``WC4$``
M``CC`%`(``3C`%```"2Y`@``IX3_X./@4!``!./@4`@`)$%04`BY`@#NIW3_
M]KD$`#O`(```%MG`Y?__^.>Y`@`BIW3_U+D$`#O`(```%M7`Y?__^-NY`@`B
MIX0`,.-`\*0`%,18``!&U>LT``,`#>,P4```"./@,`@`!./@,```)+D"`.ZG
MA/_@XR`P$``$XR`P"``D03`P"+D"`"*G=/_VN00`.\`@```6I\#E___XK;D"
M`"*G=/_4N00`.\`@```6<\#E___XH;D"`"*GA``PX^#PI``4Q"@``$:;ZQX`
M`P`-XQ`@```(XS`0"``$XS`0```DN0(`,Z>$_^#C`!`0``3C`!`(`"1!$!`(
MN0(``*=T__:Y!``[P"```!9%P.7___ASN0(`(J=T_]2Y!``[P"```!9GP.7_
M__AGN0(`(J>$`##C$/"D`!3$.```1F'K00`#``WC0#````CC`$`(``3C`$``
M`"2Y`@``IX3_X.-00!``!.-00`@`)$%`0`BY`@!5IW3_]KD$`#O`(```%CG`
MY?__^#FY`@`BIW3_U+D$`#O`(```%C+`Y?__^"VY`@`BIX0`,.,P\*0`%,1(
M``!&)^OC``,`#>/@0```".-0X`@`!.-0X```)+D"`%6GA/_@XR#@$``$XR#@
M"``D0>#@"+D"`"*G=/_VN00`.\`@```6!,#E___W_[D"`"*G=/_4N00`.\`@
M```5_<#E___W\[D"`"*GA``PXU#PI``4Q.@``$7MZQ4``P`-XQ#@```(XR`0
M"``$XR`0```DN0(`(J>$_^#C`!`0``3C`!`(`"1!$!`(N0(``*=T__:Y!``[
MP"```!7/P.7___?%N0(`(J=T_]2Y!``[P"```!60P.7___>YN0(`(J>$`##C
M$/"D`!3$*```1;/K,0`#``WC,"````CC`#`(``3C`#```"2Y`@``IX3_X.-`
M,!``!.-`,`@`)$$P,`BY`@!$IW3_]KD$`#O`(```%6+`Y?__]XNY`@`BIW3_
MU+D$`#O`(```%8[`Y?__]W^Y`@`RIX0`",`@```5>L#E___XX;D$`#O`(```
M%87`Y?__]VVY`@`RIX0`",`@```5A,#E___XS[D$`#O`(```%8+`Y?__]UNY
M`@`RIX0`&<`@```5(\#E___XO=4'\*B@**=T`"+`,```%B/`(```%37KK_$`
M``3`]/__^*RY!``[P"```!5GP.7___<XN0(`,J>$_^7`(```%2[`Y?__^)JG
M]/_=P.7___1)!P<'!^N_\%@`),`@```5'N/P_U#_<;)/`+!!,/"DZ[L`(``-
MLD\`L=('\*BP*,#E___W#[D"`"*GA``;OP$@`*>$`!?`!P```#"YA``0N0,`
M,>Q#/[\!5;D4`"35!_"HL"BG=``*Z[_Q"``$!_ZG2```I_3_\\#E___T"V``
M\(!@(/"(8$#PD&!@\)BR3P`0ZS_P&``DX_#_./]QZS$`(``-N00`0K)/`#%!
M`/%H02#PR,1H``!$^4%0\*#2!_#`,"CC(/"X`"3C`/"P`"3E2/"@``'E2/"H
M``#C(&````2G.0`!P.7___.DIRD`_\#E___S7Z=)``*G.0``ZX_P0``DX_#_
M4.]QXQ#PJ!!QN00`@K)/`*#KJ@`@``VR3P"AT@<0`*`HP.7___(#[)+__P#9
M[`DP@`!5N0(``*>D``NG"___P"'__P``N8$``J<+``&Y"0"00;#PH+D"`)FG
M1`"HITD``+D$`#FY!``HP.7___'?IR___Z>$`+7`00`!``BY!``[N00`*,#E
M___SX:<N__^GA`"AN10`,L(^````!Z?$`'[C$[_X_W&Y(0`;IT0`=^Q!/K\`
M5<!0``!$A=4'4``0`*>$`(+C$!___W&Y(0`;IT0`9;D"`$2GA``OIT\``:>$
M`!RG3P`"IX0`#<#@``!$:M4'X``0`*>$`&?C$!___W'`(```1%_5!R``$`"G
MA`!<XQ`?__]QP#```$14U0<P`!``IX0`4>,0'___<;DA`!NG1``TP$```$1%
MU0=``!``IX0`0N-0'___<<#@``!$.KD$`!75!^``4`"GA``UXQ!?__]QP"``
M`$0MU0<@`!``IX0`*L0(``!$)>,07_[_<>,`7_[_(*>$`!_C$%_]_W&Y(0`;
MIZ3_T,*4``$``,*<__\``*=T_URG*?__XX#PJ!!QU0>``*`HIW0`&.N/\/`0
M!`?^N>FP(;D(`"FG]/_PP"```!/WP.7___[0P"```!/JP.7___[*P.7___+/
MZ^_P<``DX_#_8/]QP.7___"FP.7___"#N0(`(J>$``7C("````3K[_$0``0'
M_@<'ZV_P,``DX_#_0/]QLD\`H+D$`&+KJ@`@``U!,/"TLD\`H<`@```3Q=('
M\+B@*,#E___U?;D"`+*GA``8E0"P`*>$`!2Y!``VP.7___"PN0(`(J>$`!O5
M!_"XH"BG=`!4ZV_P\``$!_[5!_"XH"BG=`!+N00`-L`@```3F^MO\/``!,#T
M___VOZ<(``"Y!``[N00`%J=)``"R7@!#IQ3__K)>`"&G%/_^N0D`2[D)`"9!
M(D`"P.7___"*P````!,2X[#PJ``DXP#PH``DN00`LL!0```3?J=)__^G.0`!
MP.7___,%U0?PN*`HIW0`#;D$`#O`(```$UWK;_#P``3`]/__]H'`Y?__\C('
M!P<'!P?K;_`P`"3C\/X0_W&R3P!PZW<`(``-LD\`<<`0``!#.[D$`-)!H/#$
MP"```!+'N00`.M('\>AP*-(/\,@0$-('\-@0(-(O\/@0*-(/\.`06-('\/`0
M:,#E___TX;D"`+*GA``&E0"P`*=T`FK`Y?__[];`Y?__[[.Y`@`BIX0!%^.P
M(````J>$`1*G"```ISD``+D$`$NR7@`TIQ3__KD)`#OK(P`!``VG*P`!P.7_
M__`&E0"P`.-@L```E+D$`)*Y!`""IX0`&[F$`&:Y!``IP%```!+RITG__Z<Y
M``'`Y?__\GU!L+`!09"0`N-@L```E)4`L`"G=/_I09#Q`,`@```2JZ?T``FG
MFP`(XR"?^/\"IX0`'KD$`#K`Y?__]'^Y`@"RIX3_\I4`L`"GA/_NP.7___3D
M$B*GA/_HN00`*\#E___PO+D"`&*G=``<09#PR.-@D````J>$`!65`&``IX0`
MH;D$`";`Y?__],@2(J=T`(RGFP`(XV"0```"IW3_[Z<(``"Y!`!8N00`)J<Y
M``"G20``LEX`,J<4__ZR7@!%IQ3__KD)`#:Y"0!(&C2G.@0$N10`L[D$`"O`
MY?__[W[`````$H'C@/"P`"3C`/"H`"2Y!`"2P%```!)QITG__Z<Y``'`@```
M$?7C@/"@`"3`Y?__\?.G.0'`N00`*<#E___PW*<N__^G=``+P.7___"E6&`@
M`*=N`!&G=`%V03#Q*+D$`"G`Y?__\4@8@A(BIW0`"UC@\4#`ZP``\`"G[D``
MIX0`>,2H``!"%+D$`&GC4-````3`0```$E?C(*````2G.0`!P.7___$8I[D`
M`-4'\>AP**=T`@>Y!``KZV_R(``$!_ZGFP`(N00`)L#E___P%+D"`&*GA/]<
MI_3_<J=I``"G]/]N08#PX.,@@````J>$`!:Y!``ZP.7___.NN0(`4J>$``:5
M`%``IW0`&:>+``CC((````*G=/_NIRD`#<"P```1Y,#E___NYZ=H`%.Y!`"2
MN00`@J?T_N;`Y?__[]RY`@"RIX3_Y*<(``"GZ0``N00`&[)>`.&G%/_^N0D`
MZ^LN``$`#:<K``&G]/Z^6&#Q1,#E___N<!EBIW3_A%@0\4#`&P```?^G'@'`
MIW3_>[D$`"O`Y?__[J^Y!``ZN00`LL`@```1^<#E___S5;D"`#*GA`#RXR#0
M```$P.7___='N0(`8J>$`.BG"```ITD``+D$`#:R7@!#IQ3__KD)`$:G3@`#
MI\0`'KD4`"3`4```$=;CXF_\_W&R70!>IQ3__J=T`!"G3@`$IX0!-Z=*__NY
M%``404%@`)4O0`"GA`$MN00`.L`@```1$\#E___S$[D"`**GA`"UXP"@``"4
M$@"GA`"OIPX`,*>$`*O`,```$=S`(```$/S`Y?__]&BY!`!IP.7__^_7P$``
M`!(`P#```!#-XT#PL``DXS#PH``DXR#PJ``DP%```!&=N00`*Z=)__^G.0`!
MP.7___"\I_0`,L#E___O=U@@(`"G+@`1IW0`-*>*``'`H```$*C`Y?__[ZG`
M4```$=*Y%``(XU#PN``DXR#PJ``DXZ#PH``DN00`:>,`\+``)+D$`"O`4```
M$7"G2?__ISD``<#E___PBJ<Y`<"Y!``KP.7__^]SIR[__Z>$_\>Y!``IP.7_
M__`ZN00`.\`@```09,#E___S_KD$`"O`Y?___/FG]/ZWN10`%L0X``!`LN,0
M\*``)+D$`&GC4-````3`0```$-3C(#````2G.0`!P.7__^^SI_3^F\#E___\
MVM4'\>AP**=T`)^Y!``KZV_R(``$P/3__^ZQXV#0```$I_3_%[D$`":G.0``
MP.7___`%N00`TA(BIX3_3<#E___[H;D"`&*G1/]&ITD``.,P;_;_<;D$`"W`
MY?__[:^G20`&03#QN;D$`"W`Y?__[[:G+P`&IW0`:\`0```P$-4%$`#QN:=T
M_R?C,&_._W&G20``N00`+<#E___MD+D$`"VG20`H0=#QO[D$`#W`Y?__[Y6G
M+P`HIW0`2L#@```1&L!@```/YY(`\>?C8/"@`"3CX/"P`"3CT/"H`"2Y!`!I
MP%```!"KITG__Z<Y``&Y!``KP.7__^_2I_3_4^/0T`@``J>$_M*G"```IRD`
M`+D$`#VR7@`CIQ3__KD)`"W"+@````.GQ/[!XU+?_/]QP.```!![LET`Y:<4
M__ZYXH!MI_3^L\#E___NZ<`@```0<,#E___ZV^M_\#@`),"@```_U>,0H```
M!./P_U#_<;)/`+!!@/"DZ[L`(``-P"````^<LD\`L;D$`#C2!_"HL"CCD;``
M``32`)"QD+#`Y?__\9VY`@`BIX0`!I4Q(`"GA`#4P.7___=^XS"@```$XY.P
M```$N00`*:=9``.G20`!P#```!!+P.7__^TPN0(`DJ>$`![C0)`0``3C<*``
M``3C,$````3C)[````3`0```$#;`Y?__[2KC4)`0``3C,%````210#`-IW0`
MMN-PH```!*=9``/C)[````2G20`!P#```!`?P.7__^T`N0(`DJ>$`!JY!``X
MP"````\;P.7___%$N0(`0J>$`(7C()`0``3C,"````3C)[````3`Y?__[/3C
MH*````2G20`!XWJP```$P#````_VN00`)\#E___L-,!````/^;D$`#*Y!``G
MP.7__^S:XSJP```$D@`PL<`@```.X;D$`#C`Y?__\0W$*P``/XZY!`""N0(`
M(J>$`"ZG.0'`N00`*,#E___MS>P"``$`V,(/`````:?$`!:G+@`1IX0`$KD$
M`%+$N```/VRY!`!(P"````_3XS"P```$P.7__^Y1U0?PJ+`HIW0`.NM_\.@`
M!`?^Q"@``#]5P.7___O&Q"L``#]3N00`@KD"`"*G=/_'P"````^AP.7__^XS
ME0`@`:>$_S6G]/\JX^"0$``$Q!@``#\WXR#@```$XS`0```$P.7___-JI_3_
M>N,GL```!,#E___MMJ?T_T;`Y?__[<$'!P<'ZY_P2``DX_#_4/]QLD\`H+D$
M`++KJ@`@``U!,/"DLD\`H<`@```.B-('\*B@*,#E___PA;D"`"*GA``4XQ`@
M``"4$A&GA``.IQX`,*>$``JY`@"[IX0`!I4`L`"G=``+U0?PJ*`HIW0`->N?
M\/@`!`?^N00`*\#E___UJ:<Y`"^Y!`"2P.7__^X:N0(`,J>$``1!D#`!N00`
M*<#E___LGZ=)``3`,```#J#`Y?__["<2(J=T_]?5!_"HH"BG=``*N00`*^N?
M\/@`!,#T___P[\#E___M5`<'05`@.*<)``3K;_`P`"3C\/S0_W&R3P"@01#P
MJ.NJ`"``#;)/`*'2!_,HH"CC0%````3C,%`(``3KM``@``SCL!```"3K8P`@
M``SC8!`0`"3`2@````#C0!`(`"3`.@````#C,!`8`"1!4%`0IQL`(*<'_][C
M,/$0``3C@/$8``3C$/$@``3CD/"H``3C0/"P``1!L/"XIUD`0+D$`''CT+``
M``2Y!`#MX^"P,`""N8(`X[F"`.GL'B"_(57L'B`^`5;C$+!P`"2Y!``XN00`
ME+D$`(>GNP`(IU<*YN,`(`@`!.,`\*``).-0(!``!..P(!@`!+GGL)6Y@`"0
MN8(`F^-`(```!.M@``(`#.PT(+\E5>Q@`"$>5NPT(#H%5NSF(+\`5>-P\+``
M!+GGX-7">EJ">9FY@`#4N0@`>[F"`-7C$/"H``2YZ'"-PAI:@GF9XQ`@(``(
MN0@`$[D(`!GLD2"_`%7L`3N_)57L"0`Z!5:Y"``(ZS0``@`,['`@OP!5[#0`
M(1Y6[-`[OR55[(,@OP!5[-<`.@56N8(`8^,0\+@`!+F``&G"&EJ">9FY@@!N
MN0@`%>,`\,``!+D(`!;""EJ">9FY"``=N0@`#NOI``(`#.SI`"$>5KF"`#[L
MD2"_`%7L83N_)56YY'`3N00`-NPY`#H%5NQN(+\`5;F"`!CCT/#(``2Y"``0
MPMI:@GF9N0@`$[GH@`WK-P`"``SL@3N_)57L-P`A'E;L<2"_`%7LAP`Z!5:Y
M@@#CXQ#PT``$N8``Z<(:6H)YF;F"`.:Y"`#@N>A@`;D(`.CL8R"_`%7KB0`"
M``SLB0`A'E:Y@@`X[)X@OP!5[-X[OR55N>1PX[D$`#WL.0`Z!5:Y@@#FXQ#P
MV``$N0@`X,(:6H)YF;D(`..YZ&`!ZS<``@`,[&@@OP!5[#<`(1Y6N8(`@^Q^
M(+\`5>S>.[\E5;GDD.BY!`"-[(<`.@56N8(`YN,0\.``!+D(`.#"&EJ">9FY
M"`#HN>A@`>N)``(`#.QC(+\`5>R)`"$>5KF"`#CLGB"_`%7LWCN_)56YY'#C
MN00`/>PY`#H%5KF"`.;C$/#H``2Y"`#@PAI:@GF9N0@`X[GH8`'K-P`"``SL
M:""_`%7L-P`A'E:Y@@"#['X@OP!5[-X[OR55N>20Z+D$`(WLAP`Z!5:Y@@#F
MXQ#P\``$N0@`X,(:6H)YF;D(`.BYZ&`!ZXD``@`,[&,@OP!5[(D`(1Y6N8(`
M..R>(+\`5>S>.[\E5;GD<..Y!``][#D`.@56N8(`YN,0\/@`!+D(`.#"&EJ"
M>9FY"`#CN>A@`>LW``(`#.QH(+\`5>PW`"$>5KF"`(/L?B"_`%7LWCN_)56Y
MY)#HN00`C>R'`#H%5KF"`.;C$/$```2Y"`#@PAI:@GF9N0@`Z+GH8`'KB0`"
M``SL8R"_`%7LB0`A'E:Y@@`X[)X@OP!5[-X[OR55N>1PX[D$`#WL.0`Z!5:Y
M@@#FXQ#Q"``$N0@`X,(:6H)YF;D(`..YZ&`!ZS<``@`,[&@@OP!5[#<`(1Y6
MN8(`@^Q^(+\`5>S>.[\E5;GDD.BY!`"-[(<`.@56N8(`YN,0\1``!+D(`.#"
M&EJ">9FY"`#HN>A@`>N)``(`#.QC(+\`5>R)`"$>5KF"`#CLGB"_`%7LWCN_
M)56YY'#CN00`/>PY`#H%5KF"`.;C$/$8``2Y"`#@PAI:@GF9N0@`X[GH8`'K
M-P`"``SL:""_`%7L-P`A'E:Y@@"#['X@OP!5[-X[OR55N>20Z+D$`(WLAP`Z
M!5:Y@@#FXQ#Q(``$N0@`X,(:6H)YF;D(`.BYZ&`!ZXD``@`,[&,@OP!5[(D`
M(1Y6N8(`..R>(+\`5>S>.[\E5;GD<..Y!``][#D`.@56N8(`YN,0\2@`!+D(
M`.#"&EJ">9FY"`#CN>A@`>LW``(`#.QH(+\`5>PW`"$>5KF"`(/L?B"_`%7L
MWCN_)56YY)#HN00`C>R'`#H%5KF"`.;C$/$P``2Y"`#@PAI:@GF9N0@`Z+GH
M8`'KB0`"``SL8R"_`%7LB0`A'E:Y@@`X[)X@OP!5[-X[OR55XQ#Q.``$N>1P
MX\(:6H)YF;D$`#WL.0`Z!5;LV""_`%6Y@@#FN0@`X+GH8`&Y"`#CZS<``@`,
M[#<`(1Y6['X[OR55N><P:.Q^(#H%5N.`\4``!,#J`````,**6H)YF;GHT!BY
M@`!IZXX``@`,N8(`;>R.`"$>5KD(`&#K"0`"``RY"`!G[`D`(1Y6[',@OP!5
MN><`T^R6.[\E5;F``-[LEB`Z!5:Y@@#7N0@`T;GG@!"Y"`#9N8(`%NSM.[\E
M5>SM(#H%5N,P\4@`!..0\5``!,(Z;MGKH<*:;MGKH;D(`#>Y&@"0N1H`,>QV
M(K\^5;D(`#[L=@(A'E;LXSN_)56YYW`8[.,@.@56N8(`'>QM(K\^5;D:`)'L
M;0(A'E:Y"`">X^#Q6``$PNINV>NAN1H`Z+GG8(>Y@@"#[`D[OR55N1H`Z.P)
M(#H%5N.`\6``!+D(`.#"BF[9ZZ'L'CN_)56Y&@"'[!X@.@56[',BOSY5[',"
M(1Y6XS#Q:``$N>=PUL(Z;MGKH;F"`-FY&@`VN1H`C>QI(K\^5;D(`('L:0(A
M'E;LF#N_)57LF"`Z!5:YYV`7L\$`:;F"`![CD/%P``2Y&@`QPIINV>NAN1H`
ME[/-`':Y"``W[-,[OR55[-,@.@56['XBOSY5XQ#Q>``$['X"(1Y6PAINV>NA
MN>=PYKD:`!:Y@@#H[&@BOSY5N1H`GNQH`B$>5KD(`)VYYV#7[(D[OR55N8(`
MT^R)(#H%5KD:`!WCX/&```2Y"``8PNINV>NA[(,BOSY5N1H`Y^R#`B$>5NP!
M.[\E5;GG@-;L`2`Z!5:Y@@#9XS#QB``$N1H`[<(Z;MGKH;D(`."Y&@`V[&DB
MOSY5[&D"(1Y6[)X[OR55[)X@.@56N>=@"+/!`'FY@@`!XY#QD``$N1H`,,*:
M;MGKH;D:`)BSS0"'N0@`..S3.[\E5>S3(#H%5NQQ(K\^5>QQ`B$>5N,0\9@`
M!+GG<`;"&F[9ZZ&Y@@`.N1H`%KD:`)#L;B*_/E6Y"`"=[&X"(1Y6[.D[OR55
MN>=@U^SI(#H%5KF"`-/C@/&@``2Y&@`=PHINV>NAN0@`'KD:`(?LXR*_/E7L
M`3N_)57LXP(A'E;L`2`Z!5:YY^#6XS#QJ``$N8(`V<(Z;MGKH;D:`(VY&@`V
MN0@`@.QI(K\^5>QI`B$>5NR8.[\E5>R8(#H%5KGG8`ZSP0!IN8(``>.0\;``
M!+D:`##"FF[9ZZ&Y&@">L\T`YKD(`#[LTSN_)57LTR`Z!5;L<2*_/E7L<0(A
M'E;C$/&X``2YYW`&PAINV>NAN8(`"+D:`!:Y&@"0[&@BOSY5N0@`G>QH`B$>
M5NR).[\E5;GG8-?LB2`Z!5:Y@@#3X^#QP``$N1H`'<+J;MGKH;D(`!BY&@#G
M[(,BOSY5[`$[OR55[(,"(1Y6[`$@.@56N>>`UN,P\<@`!+F"`-G".F[9ZZ&Y
M&@#MN1H`-KD(`.#L:2*_/E7L:0(A'E;LGCN_)57LGB`Z!5:YYV`(L\$`>;F"
M``'CD/'0``2Y&@`PPIINV>NAN1H`F+/-`(>Y"``X[-,[OR55[-,@.@56['$B
MOSY5L\$`#>QQ`B$>5NS>(K\^5;GG<`;LW@(A'E:Y@@`.N>?0A^,0\=@`!+F"
M`(/"&F[9ZZ&Y&@`6L\T`8+D:`)"Y&@`8N0@`ENR#(K\^5>SI(+\`5>R#`B$>
M5NP).[\E5;GG@&WL#@`Z!5:Y@@"6N0@`$.,P\>``!,(Z;MGKH;D:`#?L<2"_
M`%7L$3N_)57L%P`Z!5:Y&@`YXY#QZ``$N0@`,<*:CQN\W.L>``(`#+D:`)WL
M'@`A'E;LT2"_`%6YY-`(L\$`*>SC.[\E5>R3(+\`5>-@\?``!+GF$#CLZ0`Z
M!5:Y@``WPFJ/&[S<N8$`,+/-``*Y"``PN00`!KD(`#ZY&@`(Z^<``@`,XV#Q
M^``$[.<`(1Y6PFJ/&[S<N>30?KF!`!ZYZ-#6N8``&;F!`!>Y"``0[(,@OP!5
ML\$`;>PS.[\E5>PX`#H%5KD(`#'K&0`"``SL&0`A'E;LT2"_`%6YY-`.N>80
MGKF``)BY@0"0L\T`!NQS(+\`5;D(`)#L,SN_)57C8/(```3L-P`Z!5;":H\;
MO-RY!``&N1H`#NOH``(`#.SH`"$>5KGDT(ZY"`"3N8$`'NPY(+\`5;F``!?L
MF3N_)56Y@0`8[),`.@56N0@`$.N'``(`#+D(`!GLAP`A'E;C8/((``3L>""_
M`%7":H\;O-RYY'`.N>C0UNR1.[\E5;/!`#WLT2"_`%6YYH`>N8``$[F!`!"S
MS0`#[)T`.@56N0@`$.-@\A``!,)JCQN\W+D$``:Y&@`.Z^,``@`,[.,`(1Y6
MN>;@.+GD<(ZY"``9N8``/>QA(+\`5>R1.[\E5;F!`#CLE@`Z!5:Y"``PN0@`
M.>R#(+\`5>L=``(`#.P=`"$>5N,`\A@`!+GF$-[LDSN_)57""H\;O-SLF``Z
M!5:SP0!]L\$`*>S1(+\`5;D$`##CD/(@``2Y"``WPIJ/&[S<N>30?KD:`)ZS
MP0!#L\T`XK/-``2SP0!IL\T`-^N6``(`#+F``#;LE@`A'E:Y@0`WN>30:;D(
M`#"Y@0`9N0@`/KF``!BSS0`&N8$`%N/@\B@`!+D(`!#"ZH\;O-SL<R"_`%6Y
MZ-#>[#,[OR55[#<`.@56N0@`,>L8``(`#.P8`"$>5NSA(+\`5;GDX`GL8R"_
M`%6SP0`=[(,[OR55N>80.;F``#>Y@0`PL\T``>R&`#H%5KD(`##CT/(P``3C
M`/(X``3"VH\;O-S""H\;O-RY&@#9ZY<``@`,[)<`(1Y6N>3@>;F!`!FY@``6
MN8$`%[D(`!VYZ.#@N0@`..R#(+\`5>PS.[\E5>PX`#H%5KD(`#'K%@`"``SL
M%@`A'E;LT2"_`%6YY-`)[',@OP!5L\$`7NQC.[\E5;GF$#FY@``XN8$`,+/-
M``7L9P`Z!5:Y"``PX^#R0``$XP#R2``$PNJ/&[S<P@J/&[S<N1H`Z>N8``(`
M#.R8`"$>5KGDT(FY@0`9N8``%[F!`!BY"``>N>C0T+D(`#;L8R"_`%7L,SN_
M)57L-@`Z!5:Y"``QZQ<``@`,[!<`(1Y6[($@OP!5N>2`">SC(+\`5;/!`"WL
M<SN_)56YYA`YN8``-KF!`#"SS0`"['X`.@56N0@`,./0\E``!.,`\E@`!,+:
MCQN\W,(*CQN\W+D:`-GKE@`"``SLE@`A'E:YY(!IN8$`&;F``!ZY@0`6N0@`
M';GH@("Y"``W[',@OP!5[#,[OR55[#<`.@56N0@`,>L>``(`#.P>`"$>5NS1
M(+\`5;GDT`GL8R"_`%7LXSN_)56SP0!(N>80.;F``#>Y@0`PL\T`!.SF`#H%
M5KD(`##C@/)@``3"BH\;O-RY!``(N1H`">N7``(`#.R7`"$>5KGDT'FY@0`9
MN8``%KF!`!>Y"``0N0@`/N.`\F@`!.SC(+\`5<**CQN\W.PS.[\E5>P^`#H%
M5KD(`#'K%@`"``SL%@`A'E;L82"_`%6YY&`)[',@OP!5N>C0V.R#.[\E5;/!
M`!VYYA`YN8``/KF!`#"SS0`![(<`.@56N0@`,./0\G``!+D(`#C"VH\;O-RY
M!``-N1H`">S3(+\`5>N>``(`#.R>`"$>5NSC.[\E5;GD8(FY@0`9[.T`.@56
MN8``%^,P\G@`!+F!`!C".H\;O-RY"``0N>A@`[D(`.'L;CN_)57L;B`Z!5;K
M%P`"``RSP0!6[!<`(1Y6XV#R@``$[($@OP!5N>80>;GD@#FY@`!]PFJ/&[S<
MN8$`<[D:`&FY"`!PL\$`=K/-`)7C8/*(``2YZ)"7PFK*8L'6[`D[OR55ZWT`
M`@`,[`D@.@56['T`(1Y6N00`T+GD@#>YZ("&P.H`````N8$`%[/!`"BY@``>
ML\T`![F!`!/KC@`"``RY"``0[(X`(1Y6N0@`';/-`&*YYX#7XS#RD``$N8(`
MV<(ZRF+!UKD:`&VY&@`W[.$[OR55['DBOSY5[.$@.@56['D"(1Y6N0@`YK/!
M`&/L#CN_)56YYW`X[`X@.@56N8(`,>QA(K\^5>.0\I@`!.QA`B$>5L*:RF+!
MUKGG8->Y&@"8N8(`WK/!``FSS0"6N1H`D[D(`)"SS0``[!D[OR55N1H`#>P9
M(#H%5KD(`!#L,3N_)57L,2`Z!5:SP0`3L\T`T>.`\J``!.,P\J@`!,**RF+!
MUL(ZRF+!UKD:`(>Y&@`V['XBOSY5['X"(1Y6N>=PYNQI(K\^5;F"`.GL:0(A
M'E:Y&@".N>=@![D(`(VY@@`![)@[OR55N1H`,.R8(#H%5KD(`#GLTSN_)57L
MTR`Z!5;LD2*_/E7CX/*P``3LD0(A'E;"ZLIBP=:YYY`&N1H`Y[F"``BY&@#@
MN0@`[>S>.[\E5>S>(#H%5N,0\K@`!+/!`'W"&LIBP=;CT/+```2Y&@`6PMK*
M8L'6[&@BOSY5N1H`V>QH`B$>5KGG8(FY@@"#[',BOSY5N1H`&.QS`B$>5K/-
M`)>YYW"&N0@`&;F"`([L`3N_)57C,/+(``3L`2`Z!5;".LIBP=:Y&@`VN00`
M;>S>(K\^5;D:`&BY"`!@[-X"(1Y6N>?0Y[F"`.'C@/+0``3LECN_)56Y&@`^
M[)8@.@56PHK*8L'6N0@`.;D:`(?L`SN_)57L<2*_/E7L`R`Z!5;L<0(A'E;C
M$/+8``2YYW#MPAK*8L'6N8(`YKD:`!WLUB*_/E7LU@(A'E:YY]!GN8(`8[D:
M`(ZY&@`6N0@`@.R3(K\^5>P(.[\E5>R3`B$>5NP((#H%5KGGD&VY@@!HN0@`
M$./@\N``!.P!.[\E5<+JRF+!UNP!(#H%5KD:`.>Y&@#F[&@BOSY5N0@`X.QH
M`B$>5NR..[\E5;GG8'GLCB`Z!5:Y@@!QL\$`&.,P\N@`!..`\O``!,(ZRF+!
MUL**RF+!UKD:`#VY&@")N1H`-[/-`)'L<2*_/E6Y"``Y['$"(1Y6[`,[OR55
MN>=PUNP#(#H%5KF"`-[C$/+X``2Y&@"-PAK*8L'6N0@`@+D:`!;L;B*_/E7L
M;@(A'E;LZ#N_)56YYV`'[.@@.@56N8(``[D:`!"Y"``>[-$[OR55[-$@.@56
M[.,BOSY5XY#S```$[.,"(1Y6PIK*8L'6N>?@!KD:`)>Y@@`(N1H`D+D(`)WL
MV3N_)57LV2`Z!5;C,/,(``2SP0`MPCK*8L'6X]#S$``$N1H`-L+:RF+!UNQH
M(K\^5;D:`-[L:`(A'E:YYV".L\T`XKF"`(&Y&@`XN0@`/NP#.[\E5>P#(#H%
M5NR!(K\^5>SI(K\^5>R!`B$>5NSI`B$>5KGG@';C$/,8``2Y@@!YPAK*8L'6
MN1H`U[D:`!:YZ`!MN>?@".R6(+\`5;GG,'"Y!`#>[`8[OR55X]`@(``(N1H`
M%\#:`````.P)`#H%5N/0("``)+D(`!#LTR*_/E7K"0`"``SLTP(A'E;L"0`A
M'E:YZ+!]N8(`[<!Z`````.-P(!@`)+GG8+ZY"``%XS#S(``$P`H`````XP`@
M$``DPCK*8L'6XV#PH``$N0@`-.Q!(+\`5;D:`#BY"`!D[($[OR55P&H`````
MXV`@"``D[(0`.@56N00`$[D:`!NY"``8P!H`````XQ`@```DU0?S**`HIW0`
M"NMO\V``!`?^N00`3:?T]/G`Y?__X?H'!P<'!P?K[_!P`"2G*0"`X_#_8/]Q
MP.7__^`<P#%G12,!P`_OS:N)XS`@```DXP`@"``DP$^8NMS^P%$0,E1VXT`@
M$``DXU`@&``DP#_#TN'PY4@@*```XS`@(``DY4@@,```Y4P@>```Z^_Q$``$
M!_X'!P<'ZV_P,``DZQ0``P`-N00`LN,@("@`!+D(`!+L42"_`%6Y!`"4X_#_
M8/]QXT"P,``$N00`H[DQ`"&GQ``$ITL``>-0L"@`).L)`!T`#+D(``3C`+`P
M`"3CT+!X`!*G=`")07"P.*>>`#^GQ`"M[&G_P`#8B&``!NSF``$`V.P>'[D&
M5>Q1_\``V4'1H`#KA0`&``RGBP`![$@^OP!5IX0`+*=/``&GA``:IT\``J>$
M``S2/W``H`"Y!``K0:"@0,#E___T#=(_<`"@`+D$`"M!H*!`P.7___0#TC]P
M`*``N00`*T&@H$#`Y?__\_FY(`"MIX0`*>N(``(`#-(_<`"@`+D$`"O`Y?__
M\^JY!``KTC]P`*!`P.7___/BN00`*](_<`"@@,#E___SVKD$`"O2/W``H,!!
MH*$`P.7___/0IX?_WJ>:_\")8``&&Y:Y%`"9N00`/;D$`">Y!`!)P.7__^(>
M4)"P>.MO\-``!`?^IX@`0!N-&8FY!``ZN?(PB4%PL#BY%`!HN00`)[D$`$:Y
M&``MP.7__^(#&#A:,+!X4#"P>*<^`$"G=/_@&YBY"`"FN10`F;D$`"O`Y?__
M\Y"G]/]3N00`VJ?T_\4'!P<'!P?K?_`X`"2Y!`"SXX`P*``$XY`P,``$[!@Z
MOSU503`P.+D4`$&Y!`"BIQH``4%4L#B2@%``N10`(;D(`#+C\/]@_W&G'@`X
MI\0`HZ?H`$"Y^1`N&>&GA`!A[!+__P#8N00`(^M!``@`WA)$IX0`4>QT__\`
MV!A4[`0^OP!5IX0`*:<.``&GA``9IPX``J>$``OC(#0``#;7_S``,``81T$@
M,0#C("0``#;7_R``(`"G2O__02`A`.,@)```-M?_(``@`*=.``%!("$`IX0`
M(>LU``(`WN,@)```-M?_(``@`.,@)0``-M?_(0`A`.,@)@``-M?_(@`B`.,@
M)P``-M?_(P`C`$$@)`"G-O_FN18`X<;@````IKD$`"O`Y?__\O?7-[`XL#BY
M!``KIWD``.QY``=@5>QY"`]@5>QY$!=@5>QY&!\@5>R'`!\`5>.`L'``),#E
M___RV[D$`"O2`J``L`32`*`#L`?2`Z`$L`S2`Z`(L!32`Z`,L!S2`Z`0L"3K
M?_#8``3`]/__X)&G"``XN?D0<!D!IX3_R.P7__\`V+D$`"/K<0`(`-X2=Z>$
M`%'LY___`-@85^P'/K\`5:>$`"FG#@`!IX0`&:<.``*GA``+XR`T```VU_\P
M`#``&'Y!(#$`XR`D```VU_\@`"``IWK__T$@(0#C("0``#;7_R``(`"G?@`!
M02`A`*>$`"'K-0`"`-[C("0``#;7_R``(`#C("4``#;7_R$`(0#C("8``#;7
M_R(`(@#C("<``#;7_R,`(P!!("0`IS;_YKD6`$'&0`````BG]/]GUP`@`"``
MUP`@`"``Q%@``#"XP/3__]W=!P<'!^MO\#``)+D$`!^G^_]@XQ#P```DP,``
M`"^.!P?C0/$0``3K;_#0``0']`<'```````"``$E<R\E<P`O<')O8R]S96QF
M+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ
M4$%2.CI"3T]4```O<')O8R\E:2\E<P!E>&4`+@!005)?5$5-4```4$%27U!2
M3T=.04U%```Z`"\`4$523#5,24(``%!%4DQ,24(`4$523#5/4%0``%!%4DQ)
M3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?
M1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<``%!!4E]'3$]"04Q?
M5$U01$E2`%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,
M7T-,14%.``!L<V5E:R!F86EL960``')E860@9F%I;&5D`$Q$7TQ)0E)!4EE?
M4$%42`!365-414T``"4P,G@``"5S)7,E<R5S``!P87(M```E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP
M;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!0
M051(``!P87)L```N<&%R``!S:&]R="!R96%D```E<R5S8V%C:&4M)7,E<P``
M)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S```8`'!E<FP``#``4$%2
M.CI086-K97(Z.E9%4E-)3TX``#$N,#8Q`%5N86)L92!T;R!C<F5A=&4@8V%C
M:&4@9&ER96-T;W)Y```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```M90``+2T``%53
M15(``%5315).04U%``!414U01$E2`%1-4``O=&UP``!E=F%L("=E>&5C("]U
M<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N
M;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D
M4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ
M92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?
M;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I
M>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F
M:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE
M(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@
M)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@
M("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE
M"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@
M)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*
M:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@
M>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*
M<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I
M;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI
M('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE
M.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E
M;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I
M;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS
M=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR
M;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-
M4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%
M(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M
M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD[
M"FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\
M(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G
M)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E
M86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE
M;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*
M;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T
M96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@
M=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@
M>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L
M<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I
M970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@
M("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@
M("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE
M)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@
M/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD
M<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U
M=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM
M>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#
M.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P
M96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R
M96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@
M:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY
M("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I
M8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@
M(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)
M0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC
M7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S
M:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L
M96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B
M=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N
M9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F
M(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E
M=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4[
M"FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T
M(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*
M)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER
M95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@
M("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E
M<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T
M<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C
M(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z
M('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z
M+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I
M(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL
M96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64[
M"GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@
M)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q
M=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*
M?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`
M7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF
M;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF
M;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L
M97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,
M14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E
M;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF
M;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS
M92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB
M+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO
M<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG
M="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")"
M;V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L
M92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z
M.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U
M:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y
M<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE
M?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]
M?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID
M;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ
M95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T[
M"GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP
M(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B
M72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R
M9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*
M9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%
M(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O
M<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM
M>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL
M7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF
M>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I
M('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`
M05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D
M9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)
M34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2![
M"G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*
M979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@
M0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D
M,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*
M96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@
M*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I
M('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N
M(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C
M86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]
M("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN
M:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C
M;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I
M(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I
M;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P
M87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I
M('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T
M(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&
M:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B
M)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY
M("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@
M/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T
M82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@
M)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;
M0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A
M9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I
M;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]
M"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD
M;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I
M('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N
M)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS
M965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T
M7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T
M7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*
M)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N
M9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L
M>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H
M)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S
M*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N
M9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]
M*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@
M)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R
M961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I
M9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@
M9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME
M>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM
M>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I
M;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY
M("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\
M:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@
M*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R
M968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R
M968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@
M)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@
M=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]
M*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI
M8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B
M+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY
M("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE
M+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D
M=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL
M92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO
M)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O
M7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M
M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^
M<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS
M<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H
M)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I
M*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D
M($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA
M;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L
M92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R
M('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R
M>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF
M("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI3
M2$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H
M*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG
M97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D
M8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H
M95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT
M*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M
M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L
M("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;
M17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P
M-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A
M<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI:
M:7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE
M;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T[
M"D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@
M/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO
M<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE
M(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U
M<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@
M=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R
M<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E
M<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB
M97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@
M)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[
M4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@
M)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T
M<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y
M(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%
M>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI
M.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A
M8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U
M+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S
M<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N
M;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=
M(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;
M("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.
M04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#
M<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A
M<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"
M87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@
M1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H
M+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q
M=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E
M<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W
M87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z
M.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U
M:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!8
M4TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*
M<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q
M=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I
M<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V
M86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE
M=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@
M07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ
M2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@
M<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X
M('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?
M=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@
M)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@
M5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S
M(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@
M)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U
M:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ
M3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64[
M"GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I
M9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.
M5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S
M>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%2
M7T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO
M<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG
M="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`]
M(&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I
M8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I
M+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%
M(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC
M7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*
M+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE
M7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A
M8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@
M>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q
M.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7([
M"FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM
M>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M
M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@
M>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E
M;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N
M=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@
M9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O
M<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U
M8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!
M345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G
M;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]4
M14U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@
M,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R
M;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]0
M4D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X]
M(#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U
M<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I
M('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A
M8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[
M4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D
M:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM
M?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N
M86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM
M?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?
M9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@
M/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X
M*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@
M(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE
M9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F
M5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H
M;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E
M;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6
M>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92![
M"B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%
M1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T
M92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!
M3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!
M3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@
M*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*
M?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*
M<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]
M"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@
M9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R
M8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E
M;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR
M97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!
M4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P
M96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D
M:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE
M.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*
M?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$[
M"E]?14Y$7U\*``````!P97)L>'-I+F,``$-!0TA%```````````!&P,[````
M[````!S__X"P```%Y/__@S@```$(__^$,````3C__X40```!F/__A:````'(
M__^'"````@3__XFH```"1/__BI@```*`__^+$````KS__XM(```"T/__C"``
M``,,__^,*````R#__XZ(```#7/__CL````.(__^0"````\S__Y7H```$`/__
MEF````0P__^6V```!%S__YC8```$E/__F0@```2T__^:&```!13__Z"P```%
M9/__HO@```6@__^CT```!BC__[J(```&:/__NO@```:,__^\R```!LS__[\P
M```'"``````````4``````%Z4@`!>`X!&PP/H`$'#@`````4````'/__@B@`
M``!"```````````````4``````%Z4@`!>`X!&PP/H`$```````!<````'/__
M@O````#<`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.P`("F`K/SLW,R\K)R,?&
M#J`!0@M<"L_.S<S+RLG(Q\8.H`%""TX*S\[-S,O*R<C'Q@Z@`4(+```````L
M````?/__@W````".`$:*"HL)C`B-!XX&CP5&#M@#`GH*S\[-S,O*#J`!0@L`
M```X````K/__@]````%B`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.X`-T"L_.
MS<S+RLG(Q\8.H`%""P`````\````Z/__A/P```*<`$:&#H<-B`R)"XH*BPF,
M"(T'C@:/!48.V`(#`60*S\[-S,O*R<C'Q@Z@`4(+````````.````2C__X=<
M````\`!&APV(#(D+B@J+"8P(C0>.!H\%1@[((@*4"L_.S<S+RLG(QPZ@`4(+
M````````.````63__X@0````=`!>A@Z'#8@,B0N*"HL)C`B-!XX&CP5,#L@"
M`DC/SLW,R\K)R,?&#J`!````````$````:#__XA,````.``````````X```!
MM/__B'````#4`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.V$("N`K/SLW,R\K)
MR,?&#J`!0@L````0```!\/__B0P````&`````````#@```($__^)`````EP`
M1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[P(P)V"L_.S<S+RLG(Q\8.H`%""P``
M`"@```)`__^+)````#8`2HL)C`B-!XX&CP5&#L`"8,_.S<S+#J`!````````
M0````FS__XLP```!2`!&B0N*"HL)C`B-!XX&CP5&#L@B`N0*S\[-S,O*R0Z@
M`4(+7`K/SLW,R\K)#J`!1@L````````P```"L/__C#0```7<`$:*"HL)C`B-
M!XX&CP5&#M`"`P6<"L_.S<S+R@Z@`48+````````+````N3__Y'@````>`!,
MBPF,"(T'C@:/!48.T`("5@K/SLW,RPZ@`4(+````````*````Q3__Y(H````
M>`!:A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#N@"```````T```#0/__DG0```(`
M`$Z(#(D+B@J+"8P(C0>.!H\%1@[0@@0#`<`*S\[-S,O*R<@.H`%""P```!P`
M``-X__^4/````"X`1HX&CP5&#L`"8,_.#J`!````7````YC__Y1,```!"@!&
MA@Z'#8@,B0N*"HL)C`B-!XX&CP5&#N`"`EH*S\[-S,O*R<C'Q@Z@`4(+6@K/
MSLW,R\K)R,?&#J`!1@L"=@K/SLW,R\K)R,?&#J`!1@L`````3````_C__Y3\
M```&F`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#I`%`P)Z"L_.S<S+RLG(Q\8.
MH`%""P,"S@K/SLW,R\K)R,?&#J`!1@L````X```$2/__FT0```)$`$:'#8@,
MB0N*"HL)C`B-!XX&CP52#M`"`P&\"L_.S<S+RLG(QPZ@`4(+``````!````$
MA/__G5````#6`$:)"XH*BPF,"(T'C@:/!48.T`("9`K/SLW,R\K)#J`!0@L"
M6`K/SLW,R\K)#J`!1@L``````$````3(__]ZQ````H@`1H8.APV(#(D+B@J+
M"8P(C0>.!H\%1@[H`@,!Q`K/SLW,R\K)R,?&#J`!0@L`````````````/```
M!0S__YV@```6L@!.A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M`'`Q:."L_.S<S+
MRLG(Q\8.H`%""P```````"````5,__^T&````&P`2HX&CP5&#L`"`EK/S@Z@
M`0```````#P```5P__^T9````<H`3(8.APV(#(D+B@J+"8P(C0>.!H\%7@[`
M`@,!0@K/SLW,R\K)R,?&#J`!0@L````````X```%L/__M?0```)H`$:'#8@,
MB0N*"HL)C`B-!XX&CP5\#L`"`P%$"L_.S<S+RLG(QPZ@`48+```````0```%
M[/__N"`````,````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````CD````````"-(``````````$````````"S@``
M```````!`````````MX`````````#````````!CX``````````T```````!>
MJ``````````9````````N\@`````````&P`````````(`````````!H`````
M``"[T``````````<``````````@`````;__^]0````````*0``````````4`
M```````,*``````````&`````````W``````````"@````````1.````````
M``L`````````&``````````5`````````````````````P```````+W8````
M``````(````````%$``````````4``````````<`````````%P```````!/H
M``````````<````````1D``````````(`````````E@`````````"0``````
M```8`````````!X`````````"`````!O___[``````@```$`````;____@``
M`````!$P`````&____\``````````0````!O___P````````$'8`````;___
M^0`````````.````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````"[V``````````````````````````````99@```````!F&````````
M&:8````````9Q@```````!GF````````&@8````````:)@```````!I&````
M````&F8````````:A@```````!JF````````&L8````````:Y@```````!L&
M````````&R8````````;1@```````!MF````````&X8````````;I@``````
M`!O&````````&^8````````<!@```````!PF````````'$8````````<9@``
M`````!R&````````'*8````````<Q@```````!SF````````'08````````=
M)@```````!U&````````'68````````=A@```````!VF````````'<8`````
M```=Y@```````!X&````````'B8````````>1@```````!YF````````'H8`
M```````>I@```````![&````````'N8````````?!@```````!\F````````
M'T8````````?9@```````!^&````````'Z8````````?Q@```````!_F````
M````(`8`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(!@``````````````````,`("E!!4BYP;0H`````````````
M`````&'6````````7S0``````````````````%_4````````7]@```````!A
MR@```````%\Z````````8=(``````````````````&&Z````````8<``````
M`````````````&'<1T-#.B`H1&5B:6%N(#$S+C(N,"TQ."D@,3,N,BXP```N
M<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))
M+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N
M9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT
M`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?
M87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC
M;VUM96YT````````````````````````````````````````````````````
M````````````````````````````````````````````````"P````$`````
M`````@````````(X`````````C@`````````#P````````````````````$`
M`````````````!,````'``````````(````````"2`````````)(````````
M`"0````````````````````$```````````````F````!P`````````"````
M`````FP````````";``````````@````````````````````!```````````
M````-&____8``````````@````````*0`````````I``````````W`````4`
M``````````````@``````````````#X````+``````````(````````#<```
M``````-P````````"+@````&`````@`````````(`````````!@```!&````
M`P`````````"````````#"@````````,*`````````1.````````````````
M`````0``````````````3F____\``````````@```````!!V````````$'8`
M````````N@````4```````````````(``````````@```%MO___^````````
M``(````````1,````````!$P`````````&`````&`````0`````````(````
M``````````!J````!``````````"````````$9`````````1D`````````)8
M````!0``````````````"``````````8````=`````0`````````0@``````
M`!/H````````$^@````````%$`````4````5``````````@`````````&```
M`'X````!``````````8````````8^````````!CX`````````$``````````
M```````````$``````````````!Y`````0`````````&````````&3@`````
M```9.`````````;@````````````````````!``````````@````A`````$`
M````````!@```````"`8````````(!@````````^D```````````````````
M``@``````````````(H````!``````````8```````!>J````````%ZH````
M`````"P````````````````````$``````````````"0`````0`````````"
M````````7M@```````!>V````````$"0````````````````````"```````
M````````F`````$``````````@```````)]H````````GV@`````````[```
M``````````````````0``````````````*8````!``````````(```````"@
M6````````*!8````````!C`````````````````````(``````````````"P
M````#@`````````#````````N\@```````"KR``````````(````````````
M````````"``````````(````O`````\``````````P```````+O0````````
MJ]``````````"`````````````````````@`````````"````,@````&````
M``````,```````"[V````````*O8`````````@`````&```````````````(
M`````````!````#1`````0`````````#````````O=@```````"MV```````
M``(H````````````````````"``````````(````U@````$``````````P``
M`````,``````````L```````````B`````````````````````@`````````
M`````-P````(``````````,```````#`B````````+"(`````````"@`````
M```````````````(``````````````#A`````0`````````P````````````
M``````"PB``````````?`````````````````````0`````````!`````0``
M``,`````````````````````````````L*<`````````Z@``````````````
-``````$`````````````
